#!/bin/bash

if [[ -x "$(command -v conan)" ]]; then
    # Setup the conan remote if it was defined
    CONAN_OUTPUT_FILE=/tmp/conan-remote-list-output.txt

    conan search &>/dev/null
    mkdir -p /root/.conan

    # Create an empty registry if none exists
    /bin/bash -c "[ -f /root/.conan/registry.txt ] || touch /root/.conan/registry.txt"

    # Get the remote list, outputting any warnings we see.
    conan profile new ~/.conan/profiles/default --detect &>/dev/null
    conan remote list | tee ${CONAN_OUTPUT_FILE} | egrep "^WARN:"

    # Parse non-warning text to remove warnings we don't need.
    egrep -v "^WARN:" < ${CONAN_OUTPUT_FILE} | \
      awk '{print $1;}'|rev|cut -c 2-|rev| \
      xargs -I@ conan remote remove @

    rm -f ${CONAN_OUTPUT_FILE}
fi